# Recommender systems toolkit

Simple and lightweight toolkit for building recommender systems.
## Installation
```sh
pip install rstk
```

## Usage

```sh
rstk build <algorithm> <dataset> [model-path]
```
For further information dive into the [examples](https://github.com/rat-nick/rstk/tree/main/examples).